Page 7 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 7

Home

    power ("that great city, which reigneth over the kings of
    the earth" Rev. 17:18) he also foretold its sudden loss of

    wealth and total destruction, all coming at a time when
    its leaders were at the height of their smug confidence.
    The Apostle labeled this evil center of world control

    mn

    "Mystery, Babylon The Great."

    In order to show the similarity between Mystery
    Babylon's days and what has transpired during the
    twentieth century, we will detail the events of each
    period, events often on the secret side of history.

    Lest our readers take refuge in Scripture's predicted
    fall of any Mystery Babylon, we hasten to quote an
    imperative command given to believers concerning this
    or any evil design for world power. In Revelation 18:4,
    the Apostle John relays this message:

    Come out of her, my people, that ye be not partakers of
    her sins, and that ye receive not of her plagues.

    xi

    Introduction

    only did the Apostle describe its attributes and center of